pyramid_localize
================

**Pyramid_localize** is package, that helps built fully localized packages based on pyramid framework. It provides configuration based settings for adding translation, generated translation methods or both templates and request object, and a simple web interface to generate .po files out of .pot, compile them to .mo and reload translation without restarting the application itself.

.. image:: https://travis-ci.org/fizyk/pyramid_localize.png?branch=master
    :target: https://travis-ci.org/fizyk/pyramid_localize
    :alt: Tests for RandomWords

.. image:: https://coveralls.io/repos/fizyk/pyramid_localize/badge.png?branch=master
    :target: https://coveralls.io/r/fizyk/pyramid_localize?branch=master
    :alt: Coverage Status

.. image:: https://pypip.in/v/pyramid_localize/badge.png
    :target: https://crate.io/packages/pyramid_localize/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pyramid_localize/badge.png
    :target: https://crate.io/packages/pyramid_localize/
    :alt: Number of PyPI downloads

Contents
--------

.. toctree::
   :maxdepth: 2

   basic
   advanced
   api

TODO
----

* web interface to edit .po files
